==> truera-12.2.2-py3-none-any.whl: truera/utils/data_constants.py <==
# Matches java/common/src/main/java/com/truera/common/util/Constants.java
NORMALIZED_ID_COLUMN_NAME = "__truera_id__"
NORMALIZED_RANKING_GROUP_ID_COLUMN_NAME = "__truera_ranking_group_id__"
NORMALIZED_RANKING_ITEM_ID_COLUMN_NAME = "__truera_ranking_item_id__"
NORMALIZED_TIMESTAMP_COLUMN_NAME = "__truera_timestamp__"
NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME = "__truera_event_timestamp__"
NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME = "__truera_ingestion_timestamp__"
NORMALIZED_PREDICTION_COLUMN_NAME = "__truera_prediction__"
NORMALIZED_LABEL_COLUMN_NAME = "__truera_label__"
NORMALIZED_TAGS_COLUMN_NAME = "__truera_tags__"
NORMALIZED_TOKENS_COLUMN_NAME = "__truera_tokens__"
NORMALIZED_EMBEDDINGS_COLUMN_NAME = "__truera_embeddings__"
NORMALIZED_INTERNAL_ID_COLUMN_NAME = "__truera_internal_id__"

SYSTEM_COLUMNS = [
    NORMALIZED_ID_COLUMN_NAME, NORMALIZED_RANKING_GROUP_ID_COLUMN_NAME,
    NORMALIZED_RANKING_ITEM_ID_COLUMN_NAME, NORMALIZED_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_PREDICTION_COLUMN_NAME, NORMALIZED_LABEL_COLUMN_NAME,
    NORMALIZED_TAGS_COLUMN_NAME, NORMALIZED_TOKENS_COLUMN_NAME,
    NORMALIZED_EMBEDDINGS_COLUMN_NAME, NORMALIZED_INTERNAL_ID_COLUMN_NAME
]

SYSTEM_COLUMNS_TO_DROP = [
    NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME, NORMALIZED_TAGS_COLUMN_NAME,
    NORMALIZED_TOKENS_COLUMN_NAME, NORMALIZED_EMBEDDINGS_COLUMN_NAME,
    NORMALIZED_INTERNAL_ID_COLUMN_NAME
]

==> truera-12.5.1-py3-none-any.whl: truera/utils/data_constants.py <==
# Matches java/common/src/main/java/com/truera/common/util/Constants.java
NORMALIZED_ID_COLUMN_NAME = "__truera_id__"
NORMALIZED_RANKING_GROUP_ID_COLUMN_NAME = "__truera_ranking_group_id__"
NORMALIZED_RANKING_ITEM_ID_COLUMN_NAME = "__truera_ranking_item_id__"
NORMALIZED_TIMESTAMP_COLUMN_NAME = "__truera_timestamp__"
NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME = "__truera_event_timestamp__"
NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME = "__truera_ingestion_timestamp__"
NORMALIZED_PREDICTION_COLUMN_NAME = "__truera_prediction__"
NORMALIZED_LABEL_COLUMN_NAME = "__truera_label__"
NORMALIZED_TAGS_COLUMN_NAME = "__truera_tags__"
NORMALIZED_TOKENS_COLUMN_NAME = "__truera_tokens__"
NORMALIZED_EMBEDDINGS_COLUMN_NAME = "__truera_embeddings__"
NORMALIZED_INTERNAL_ID_COLUMN_NAME = "__truera_internal_id__"
NORMALIZED_ID_HASH_COLUMN_NAME = "__truera_id_hash__"

SYSTEM_COLUMNS = [
    NORMALIZED_ID_COLUMN_NAME, NORMALIZED_RANKING_GROUP_ID_COLUMN_NAME,
    NORMALIZED_RANKING_ITEM_ID_COLUMN_NAME, NORMALIZED_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_PREDICTION_COLUMN_NAME, NORMALIZED_LABEL_COLUMN_NAME,
    NORMALIZED_TAGS_COLUMN_NAME, NORMALIZED_TOKENS_COLUMN_NAME,
    NORMALIZED_EMBEDDINGS_COLUMN_NAME, NORMALIZED_INTERNAL_ID_COLUMN_NAME,
    NORMALIZED_ID_HASH_COLUMN_NAME
]

SYSTEM_COLUMNS_TO_DROP = [
    NORMALIZED_EVENT_TIMESTAMP_COLUMN_NAME,
    NORMALIZED_INGESTION_TIMESTAMP_COLUMN_NAME, NORMALIZED_TAGS_COLUMN_NAME,
    NORMALIZED_TOKENS_COLUMN_NAME, NORMALIZED_EMBEDDINGS_COLUMN_NAME,
    NORMALIZED_INTERNAL_ID_COLUMN_NAME, NORMALIZED_ID_HASH_COLUMN_NAME
]
